// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef CCOLOR_HPP
#define CCOLOR_HPP

#include "GTypes.hpp"

/** @brief class representing a single color of the TTDX palette
 *
 * A color is made up of the rgb values and a flag that denotes if the color 
 * is some special color (transparent blue, action colors, ...)
 */
class CColor
{
public:
   /// standard constructor
   CColor();

   /** constructor
    *  @param r value of red component
    *  @param g value of green component
    *  @param b value of blue component
    */
   CColor(const UInt32 r, const UInt32 g, const UInt32 b);

   /** equal operator
    *  @param rhs color to compare with
    *  @return true if color values are identical, false if not
    */
   const bool operator==(const CColor& rhs) const;

   /** retrieve the red component value
    *  @return the value of the red component
    */
	const UInt32 r(void) const;

   /** retrieve the green component value
    *  @return the value of the green component
    */
	const UInt32 g(void) const;

   /** retrieve the blue component value
    *  @return the value of the blue component
    */
	const UInt32 b(void) const;

   /** retrieve the special flag denoting if the color is some special color
    *  @return the value of the special flag
    */
   const bool isSpecial(void) const;

   /** set the special flag of the color
   */
   void setSpecial(void);
private:
   /// the value of the red component
	UInt32 mRed;
   /// the value of the green component
	UInt32 mGreen;
   /// the value of the blue component
	UInt32 mBlue;
   /// the flag indicating whether it is a special color
   bool mIsSpecial;
};

inline
const bool CColor::operator ==(const CColor& rhs) const
{
   return (mRed == rhs.r() && mGreen == rhs.g() && mBlue == rhs.b());
}

inline
const UInt32 CColor::r(void) const
{
	return mRed;
}

inline
const UInt32 CColor::g(void) const
{
	return mGreen;
}

inline
const UInt32 CColor::b(void) const
{
	return mBlue;
}

inline
const bool CColor::isSpecial(void) const
{
   return mIsSpecial;
}

inline
void CColor::setSpecial(void)
{
   mIsSpecial = true;
}
#endif
