// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef CCOLOROPTION_HPP
#define CCOLOROPTION_HPP

#include <vector>
#include <string>

#include "GTypes.hpp"
#include "COptionObjects.hpp"

/// class defining a color that can be used for replacements
class CColorOption : public COptionObject
{
public:
   /// constructor
   CColorOption();

   /** checks the validity of the option
    *  @param options list of previously defined options
    *  @return true if option is valid, false otherwise
    */
   bool isValid(COptions* options) const;

   /** finalizes the color option
    *  @param options list of previously defined options
    */
   void finalize(COptions* options);

   /** add a line from the option file to the option
    *  @param line line to be added
    */
   void addLine(std::string& line);

   /** get the name of the color option
    *  @return the name of the color
    */
   std::string name(void) const;

   /** get the palette indices of the color
    *  @return the palette indices of the color
    */
   std::vector<UInt32> indices(void) const;
   
   /** get the palette used for this color option
    *  @return true if its dos palette, false for win
    */
   const bool isDos(void) const;
private:
   /// the name of the color
   std::string mName;
   /// the indices of the color
   std::vector<UInt32> mIndices;
   /// the RGB values of the color
   std::vector<UInt32> mValues;
   /// the palette of the color
   bool mDosPalette;

   /// internal check method to check if the option name is valid
   const UInt32 isNameValid(COptions* options) const;

   /// internal check method to check if the given index/indices is/are valid
   const UInt32 isIndexValid(COptions*) const;

   /// internal check method to check if the given value(s) is/are valid
   const UInt32 isValueValid(COptions*) const;

   /// add a color definition line
   void addColorDefinition(const std::string& type, const std::string& value);
};

inline
std::string CColorOption::name(void) const
{
   return mName;
}

inline
std::vector<UInt32> CColorOption::indices(void) const
{
   return mIndices;
}

inline
const bool CColorOption::isDos(void) const
{
   return mDosPalette;
}

#endif
