// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#include "CGenericOption.hpp"
#include "COptions.hpp"

#include <boost/regex.hpp>

CGenericOption::CGenericOption()
: mOutput("recolor.txt")
, mVerbose(false)
{
}

bool CGenericOption::isValid(COptions* options) const
{
   bool result = true;
   if (options->getGenericOption())
   {
      printErrorMessage(E_GENERIC_MULTIPLE);
      result = false;
   }
   return result;
}

void CGenericOption::finalize(COptions* /*options*/)
{
} //lint !e1961 cannot be made const

void CGenericOption::setVerbose(const std::string& v)
{
   if (v == "true" || v == "on")
   {
      mVerbose = true;
   }
   if (v == "false" || v == "off")
   {
      mVerbose = false;
   }
}
   
void CGenericOption::addLine(std::string& line)
{
   // a line always has to have the format option = value
   // non-matching lines are ignored
   const boost::regex option("([a-zA-Z]+)( ?)=( ?)(.+)");
   boost::smatch match;

   if (boost::regex_match(line, match, option))
   {
      std::string t = match[1].str();
      // I don't know why, but lint complains that it does not know std::transform
      static_cast<void>(std::transform(t.begin(), t.end(), t.begin(), tolower));//lint !e1025
      std::string t2 = match[4].str();
      static_cast<void>(std::transform(t2.begin(), t2.end(), t2.begin(), tolower));//lint !e1025
      if (t == "output")
      {
         mOutput = match[4].str();
      }
      if (t == "verbose")
      {
         setVerbose(t2);
      }
   }
}
