// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef CGENERICOPTION_HPP
#define CGENERICOPTION_HPP

#include <vector>
#include <string>

#include "GTypes.hpp"
#include "COptionObjects.hpp"

/// generic option object, describes things like output file etc.
class CGenericOption : public COptionObject
{
public:
   /// constructor
   CGenericOption();

   /** check validity of option
    *  @param options previously defined options
    *  @return true if option is valid, false otherwise
    */
   bool isValid(COptions* options) const;

   /** finalize option - empty implementation
    *  @param options list of previously defined options, unused
    */
   void finalize(COptions* options);

   /** add a line from the config file to the option
    *  @param line line to be added to option
    */
   void addLine(std::string& line);

   /** get the name of the output file
    *  @return output the name of the output file
    */
   const std::string output(void) const;

   /** get the value of the verbose flag
    *  @return true if verbose is set, false otherwise
    */
   const bool verbose(void) const;

private:
   /// the name of the output file
   std::string mOutput;
   /// indicates whether extended info should be added to table
   bool mVerbose;

   /// set verbosity
   void setVerbose(const std::string& verbose);
};

inline
const std::string CGenericOption::output(void) const
{
   return mOutput;
}

inline
const bool CGenericOption::verbose(void) const
{
   return mVerbose;
}

#endif
