// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef CMERGEOPTION_HPP
#define CMERGEOPTION_HPP

#include "COptionObjects.hpp"

#include <string>
#include <vector>

/// merge option that details which replace options to combine with each other
class CMergeOption : public COptionObject
{
public:
   /** check the validity of the option
    *  @param options list of previously encountered options
    *  @return true if option is valid, false otherwise
    */
   bool isValid(COptions* options) const;
   
   /** finalize the option, i.e. work on the given merge options and do the necessary replacements
    *  @param options list of previously defined options
    */
   void finalize(COptions* options);

   /** parse a line of the config file into the option
    *  @param line the line to be added
    */
   void addLine(std::string& line);
private:
   /// the replace options that are to be merged
   std::vector<std::string> mMergeOptions;
   /// the replace options that are to be combined
   std::vector<std::string> mCombineOptions;

   // check which indices are used by the options that are to be merged
   bool countUsedIndices(const std::vector<std::string>& indices, std::vector<UInt32>& used, COptions* options) const;

   /// check names of given options
   bool checkGivenOptions(const std::vector<std::string>& indices,COptions* options) const;

   /// check if merge options work on same palette
   bool samePalette(const std::vector<std::string>& merge, COptions* options) const;
};

#endif
