// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef IOPTIONOBJECTS_HPP
#define IOPTIONOBJECTS_HPP

#include <string>
#include <vector>
#include "GTypes.hpp"

class COptions;

/// @brief interface class for configuration options
class COptionObject
{
public:
   /// destructor
   virtual ~COptionObject() { };

   /** checks if the option is valid
    *  @return true if option is valid, false otherwise
    */
   virtual bool isValid(COptions*) const = 0;

   /** finalize the option
    *
    *  Depending on the option type, various operations have to be carried out 
    *  after having finished reading the option from the file. This is done 
    *  in this method.
    */
   virtual void finalize(COptions*) = 0;

   /** add a line from the config file
    *
    *  The line is passed into the actual option where it is processed. The 
    *  processing itself is depending on the type of the option.
    */
   virtual void addLine(std::string&) = 0;

   /** print an error message
    *
    *  Any error that is encountered in any option results in calling this
    *  method.
    */
   virtual void printErrorMessage(const UInt32 error) const;

   enum E_ERRORS
   {
      E_NO_ERROR = 0,
      E_COLOR_NO_NAME_DEFINED = 1,
      E_COLOR_NAME_CONTAINS_WHITESPACES = 2,
      E_COLOR_NAME_IN_USE = 4,
      E_COLOR_NOTHING_DEFINED = 8,
      E_COLOR_INDEX_OUT_OF_RANGE = 16,
      E_COLOR_INCORRECT_VALUE_COUNT = 32,
      E_COLOR_VALUE_OUT_OF_RANGE = 64,
      E_COLOR_NOT_IN_PALETTE = 128,
      E_GENERIC_MULTIPLE = 256,
      E_REPLACE_UNDEFINED = 512,
      E_REPLACE_COLOR_UNDEFINED = 1024,
      E_REPLACE_SIZE_MISMATCH = 2048,
      E_MERGE_OPTION_UNDEFINED = 4096,
      E_MERGE_OPTION_NUMBER = 8192,
      E_MERGE_INDICES = 16384,
      E_MERGE_PALETTE = 32768
   };
};

#endif
