// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef CPALETTE_HPP
#define CPALETTE_HPP

#include "GTypes.hpp"
#include <vector>
#include "CColor.hpp"

/// class defining a 256 color palette as used in TTDX
//lint -esym(1712,CPalette)
class CPalette
{
public:
   /** constructor
    *  @param dos defines if this is to be a dos palette, if false then its windows
    */
   explicit CPalette(bool dos);

   /** get the palette index of the given color
    *  @param r red value
    *  @param g green value
    *  @param b blue value
    *  @return palette index of the color, INT_MAX if not in the palette
    */
   const UInt32 getIndex(const UInt32 r, const UInt32 g, const UInt32 b) const;
   
   /** get the palette index of the given color
    *  @param color the color
    *  @return palette index of the color, INT_MAX if not in the palette
    */
   const UInt32 getIndex(const CColor& color) const;

   /** returns the color at the given index
    *  @param index the index to look for
    *  @return the color at the given index
    */
   const CColor getColor(const UInt32 index) const;
private:
   /// the colors that are in the palette
   std::vector<CColor> mColors;
   /// palette state (true=dos, false=win (default))
   bool mDos;
   /// initialize the palette
   void init(void);
};

inline
const CColor CPalette::getColor(const UInt32 index) const
{
   return mColors[index];
}

inline
const UInt32 CPalette::getIndex(const UInt32 r, const UInt32 g, const UInt32 b) const
{
   CColor c(r,g,b);
   return getIndex(c);
}

#endif
