// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef CRECOLORAPPLICATION_HPP
#define CRECOLORAPPLICATION_HPP

#include "COptions.hpp"

//lint -esym(1712,CRecolorApplication)
class CRecolorApplication
{
public:
   /** constructor, taking command line parameters
    *  @param options the command line options to be used
    */
   explicit CRecolorApplication(const COptions& options);

   /// the run method - called from outside to start operation
   int run(void);

private:
   /// the options to be used for the application
   COptions mOptions;

   /// recolor tables that have been written (used for application on images)
   std::vector<CRecolorTable> mTables;

   /// flag telling if detailed information about the tables is to be written
   bool mVerbose;

   /// write a recolor table to the given output
   void writeTable(std::ofstream& output, const CReplaceOption* const r);

   /// write the header of a recolor table
   void writeTableDescription(const UInt32 k, 
                              const UInt32 number, 
                              std::ofstream& output, 
                              const CReplaceOption* const r) const;

   /// apply the recoloring on the given images
   void applyOnImages(void);
};

#endif
