// This file is part of TTDXRecolor.
// Copyright (c) 2010, Uwe Domaratius

#ifndef CRECOLORTABLE_HPP
#define CRECOLORTABLE_HPP

#include "GTypes.hpp"
#include <vector>
#include <string>

/// a recolor table for TTDX
class CRecolorTable
{
public:
   /// constructor
   CRecolorTable();

   /** set a value of the table at the given index
    *  @param index the index to be set
    *  @param the value to be set
    */
   void setEntry(const UInt32 index, const UInt32 value);

   /** retrieve the table entry at a given index
    *  @param index the position in the table that is to be retrieved
    *  @return the table value at the given index
    */
   const UInt32 getEntry(const UInt32 index) const;

   /** set if this recolor table is applied for dos
    *  @param isDos true for dos tables, false (default) for win
    */
   void setPalette(const bool isDos);

   /** returns the value of the dos / win flag
    *  @return the value of the dos / win flag (true for dos, false for win)
    */
   const bool isDosPalette(void) const;
private:
   /// the actual table entries
   std::vector<UInt32> mEntries;
   /// palette (true = dos, false = win)
   bool mIsDos;
   
   /// initialization method
   void init(void);
};

inline
const UInt32 CRecolorTable::getEntry(const UInt32 index) const
{
   return mEntries[index];
}

inline
void CRecolorTable::setPalette(const bool isDos)
{
   mIsDos = isDos;
}

inline
const bool CRecolorTable::isDosPalette(void) const
{
   return mIsDos;
}

#endif
